==> haskell-setenv-0.1.1.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-setenv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 setenv
version:              0.1.1.3
visibility:           public
id:                   setenv-0.1.1.3-14IuD5zDhOEiWGeHA0oQJ
key:                  setenv-0.1.1.3-14IuD5zDhOEiWGeHA0oQJ
license:              MIT
copyright:            (c) 2012-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A cross-platform library for setting environment variables
description:
    A cross-platform library for setting environment variables

    Note: Since @base- 4.7.0.0@ the functions @setEnv@ and
    @unsetEnv@ are provided by @System.Environment@.
    @System.SetEnv@ merily re-exports those functions when built
    with @base >= 4.7@.

category:             System
abi:                  4e75110e0c7c089d073801d5b9547fdc
exposed:              True
exposed-modules:      System.SetEnv
import-dirs:          /usr/lib/ghc-9.0.1/site-local/setenv-0.1.1.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/setenv-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/setenv-0.1.1.3
hs-libraries:         HSsetenv-0.1.1.3-14IuD5zDhOEiWGeHA0oQJ
depends:              base-4.15.0.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-setenv/html/setenv.haddock
haddock-html:         /usr/share/doc/haskell-setenv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-setenv-0.1.1.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-setenv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 setenv
version:              0.1.1.3
visibility:           public
id:                   setenv-0.1.1.3-KTYV4DvUbeGDVcVTxisS4U
key:                  setenv-0.1.1.3-KTYV4DvUbeGDVcVTxisS4U
license:              MIT
copyright:            (c) 2012-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A cross-platform library for setting environment variables
description:
    A cross-platform library for setting environment variables

    Note: Since @base- 4.7.0.0@ the functions @setEnv@ and
    @unsetEnv@ are provided by @System.Environment@.
    @System.SetEnv@ merily re-exports those functions when built
    with @base >= 4.7@.

category:             System
abi:                  ae939202abf9669330cbb4c57a321243
exposed:              True
exposed-modules:      System.SetEnv
import-dirs:          /usr/lib/ghc-9.0.2/site-local/setenv-0.1.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/setenv-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/setenv-0.1.1.3
hs-libraries:         HSsetenv-0.1.1.3-KTYV4DvUbeGDVcVTxisS4U
depends:              base-4.15.1.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-setenv/html/setenv.haddock
haddock-html:         /usr/share/doc/haskell-setenv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
